@@ -1,8 +1,18 @@
+/* Copyright (c) 2009-2010 Denis Bilenko. See LICENSE for details. */
+
+#ifdef WIN32
+#include "winsock2.h" // for timeval
+#endif
+
 #include "sys/queue.h"
 
-#ifdef USE_LIBEVENT_2
+#include "event.h"
 
-#warning "Using libevent2"
+#if defined(_EVENT_NUMERIC_VERSION) && _EVENT_NUMERIC_VERSION >= 0x2000000
+
+#if _EVENT_NUMERIC_VERSION >= 0x02000900
+#define LIBEVENT_HTTP_MODERN
+#endif
 
 #include "event2/event.h"
 #include "event2/event_struct.h"
@@ -17,19 +27,21 @@
 
 #define EVBUFFER_DRAIN evbuffer_drain
 #define EVHTTP_SET_CB  evhttp_set_cb
+#define EVBUFFER_PULLUP(BUF, SIZE) evbuffer_pullup(BUF, SIZE)
 
-#elif USE_LIBEVENT_1
+#if _EVENT_NUMERIC_VERSION >= 0x02000500
+#define current_base event_global_current_base_
+#endif
 
-#warning "Using libevent1"
+#else
 
-#include "event.h"
 #include "evhttp.h"
 #include "evdns.h"
 
 /* compatibility */
 
 #define evbuffer_get_length EVBUFFER_LENGTH
-#define evbuffer_pullup(BUF, SIZE) EVBUFFER_DATA(BUF)
+#define EVBUFFER_PULLUP(BUF, SIZE) EVBUFFER_DATA(BUF)
 
 #define TAILQ_FIRST(head) ((head)->tqh_first)
 #define	TAILQ_NEXT(elm, field) ((elm)->field.tqe_next)
@@ -38,9 +50,29 @@
 #define EVBUFFER_DRAIN(A, B) (evbuffer_drain((A), (B)), 0)
 #define EVHTTP_SET_CB(A, B, C, D) (evhttp_set_cb((A), (B), (C), (D)), 0)
 
-#else
+#ifndef EVHTTP_REQ_PUT
+#define EVHTTP_REQ_PUT -1
+#endif
 
-#error "Please define either USE_LIBEVENT_1 or USE_LIBEVENT_2"
+#ifndef EVHTTP_REQ_DELETE
+#define EVHTTP_REQ_DELETE -1
+#endif
+
+#ifndef EVHTTP_REQ_OPTIONS
+#define EVHTTP_REQ_OPTIONS -1
+#endif
+
+#ifndef EVHTTP_REQ_TRACE
+#define EVHTTP_REQ_TRACE -1
+#endif
+
+#ifndef EVHTTP_REQ_CONNECT
+#define EVHTTP_REQ_CONNECT -1
+#endif
+
+#ifndef EVHTTP_REQ_PATCH
+#define EVHTTP_REQ_PATCH -1
+#endif
 
 #endif
 
