@@ -255,8 +255,13 @@ if sys.version_info[:2] <= (2, 4):
 
 if sys.version_info[:2] < (2, 7):
     _get_memory = buffer
+elif sys.version_info[:2] < (3, 0):
+    def _get_memory(string, offset):
+        try:
+            return memoryview(string)[offset:]
+        except TypeError:
+            return buffer(string, offset)
 else:
-
     def _get_memory(string, offset):
         return memoryview(string)[offset:]
 
@@ -264,7 +269,7 @@ else:
 class _closedsocket(object):
     __slots__ = []
 
-    def _dummy(*args):
+    def _dummy(*args, **kwargs):
         raise error(EBADF, 'Bad file descriptor')
     # All _delegate_methods must also be initialized here.
     send = recv = recv_into = sendto = recvfrom = recvfrom_into = _dummy
@@ -674,6 +679,8 @@ else:
         # TODO: this is supposed to iterate through all the addresses
         # could use a global dict(hostname, iter)
         # - fix these nasty hacks for localhost, ips, etc.
+        if isinstance(hostname, unicode):
+            hostname = str(hostname)
         if not isinstance(hostname, str) or '.' not in hostname:
             return _socket.gethostbyname(hostname)
         if _ip4_re.match(hostname):
